"use strict";

var _webpack = _interopRequireDefault(require("webpack"));

var _webpackDevServer = _interopRequireDefault(require("webpack-dev-server"));

var _path = require("path");

var _fsExtra = require("fs-extra");

var _chalk = _interopRequireDefault(require("chalk"));

var _formatWebpackMessages = _interopRequireDefault(require("react-dev-utils/formatWebpackMessages"));

var _printHostingInstructions = _interopRequireDefault(require("react-dev-utils/printHostingInstructions"));

var _FileSizeReporter = _interopRequireDefault(require("react-dev-utils/FileSizeReporter"));

var _printBuildError = _interopRequireDefault(require("react-dev-utils/printBuildError"));

var _browsersHelper = require("react-dev-utils/browsersHelper");

var _WebpackDevServerUtils = require("react-dev-utils/WebpackDevServerUtils");

var _clearConsole = _interopRequireDefault(require("react-dev-utils/clearConsole"));

var _webpackConfig = _interopRequireDefault(require("../../config/webpack.config.dev"));

var _webpackConfig2 = _interopRequireDefault(require("../../config/webpack.config.prod"));

var _webpackDevServer2 = _interopRequireDefault(require("../../config/webpackDevServer.config"));

var _utils = require("../../utils");

var _paths = _interopRequireDefault(require("../../paths"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const files = [_paths.default.html, _paths.default.js, _paths.default.ts];
const checkedFiles = files.map(file => (0, _utils.checkRequiredFiles)(file));
const failedCheckedFiles = checkedFiles.filter(x => x.success === false);

if (failedCheckedFiles) {
  let shouldFail = false;
  const failedHtml = failedCheckedFiles.find(x => x.fileName === 'index.html');
  const failedJs = failedCheckedFiles.find(x => x.fileName === 'index.js');
  const failedTs = failedCheckedFiles.find(x => x.fileName === 'index.tsx');

  if (failedHtml || failedJs && failedTs) {
    const failMessage = failedHtml ? failedHtml.message : failedTs.message;
    console.log(failMessage);
    shouldFail = true;
  }

  if (shouldFail) {
    process.exit(1);
  }
} // Process CLI arguments


const argv = process.argv.slice(2);
const writeStatsJson = argv.indexOf('--stats') !== -1;
const config = process.env.NODE_ENV === 'production' ? _webpackConfig2.default : _webpackConfig.default;

if (process.env.SCRIPTS_BUILD) {
  const copyPublicFolder = () => {
    (0, _fsExtra.copySync)(_paths.default.public, _paths.default.output, {
      dereference: true,
      filter: file => file !== _paths.default.html
    });
  };

  const createBundleStats = bundleStats => new Promise((resolve, reject) => {
    (0, _fsExtra.writeFile)((0, _path.join)(_paths.default.output, 'bundle-stats.json'), bundleStats, err => {
      if (err) {
        reject(err);
        return;
      }

      resolve();
    });
  });

  const build = () => {
    console.log('Creating an optimized production build...');
    console.log();
    return new Promise((resolve, reject) => {
      const compiler = (0, _webpack.default)(config);
      compiler.run(async (err, stats) => {
        if (err) {
          return reject(err);
        }

        const messages = (0, _formatWebpackMessages.default)(stats.toJson({}, true));

        if (messages.errors.length) {
          // Only keep the first error. Others are often indicative
          // of the same problem, but confuse the reader with noise.
          if (messages.errors.length > 1) {
            messages.errors.length = 1;
          }

          return reject(new Error(messages.errors.join('\n\n')));
        }

        if (process.env.CI && (typeof process.env.CI !== 'string' || process.env.CI.toLowerCase() !== 'false') && messages.warnings.length) {
          console.log(_chalk.default.yellow('\nTreating warnings as errors because process.env.CI = true.\n' + 'Most CI servers set it automatically.\n'));
          return reject(new Error(messages.warnings.join('\n\n')));
        }

        const resolveArgs = {
          stats,
          warnings: messages.warnings
        };

        if (writeStatsJson) {
          await createBundleStats(JSON.stringify(stats.toJson()));
        }

        return resolve(resolveArgs);
      });
    });
  };

  const measureFileSizesBeforeBuild = _FileSizeReporter.default.measureFileSizesBeforeBuild;
  const printFileSizesAfterBuild = _FileSizeReporter.default.printFileSizesAfterBuild; // These sizes are pretty large. We'll warn for bundles exceeding them.

  (async () => {
    try {
      // First, read the current file sizes in dist directory.
      // This lets us display how much they changed later.
      const previousFileSizes = await measureFileSizesBeforeBuild(_paths.default.output); // Remove all content but keep the directory so that
      // if you're in it, you don't end up in Trash

      (0, _fsExtra.emptyDirSync)(_paths.default.output); // Merge with the public folder

      copyPublicFolder(); // Start the webpack build

      const {
        stats,
        warnings
      } = await build();

      try {
        if (warnings.length) {
          console.log(_chalk.default.yellow('Compiled with warnings.\n'));
          console.log(warnings.join('\n\n'));
          console.log( // eslint-disable-next-line prefer-template
          '\nSearch for the ' + _chalk.default.underline(_chalk.default.yellow('keywords')) + ' to learn more about each warning.');
          console.log( // eslint-disable-next-line prefer-template
          'To ignore, add ' + _chalk.default.cyan('// eslint-disable-next-line') + ' to the line before.\n');
        } else {
          console.log(_chalk.default.green('Compiled successfully.\n'));
        }

        console.log('File sizes after gzip:\n');
        printFileSizesAfterBuild(stats, previousFileSizes, _paths.default.output, 512 * 1024, 1024 * 1024);
        console.log();
        const publicPath = config.output.publicPath;
        const buildFolder = _paths.default.output;
        (0, _printHostingInstructions.default)(_utils.pkg, '/', publicPath, buildFolder, false);
        (0, _browsersHelper.printBrowsers)(_utils.appDirectory);
      } catch (err) {
        console.log(_chalk.default.red('Failed to compile.\n'));
        (0, _printBuildError.default)(err);
        process.exit(1);
        return;
      }
    } catch (err) {
      if (err && err.message) {
        console.log(err.message);
      }

      process.exit(1);
      return;
    }

    process.exit(0);
  })();
} else {
  (async () => {
    try {
      const DEFAULT_PORT = parseInt(process.env.PORT, 10) || 3000;
      const HOST = process.env.HOST || '0.0.0.0';
      const isInteractive = process.env.NO_INTERACTIVE === 'true' ? false : process.stdout.isTTY;
      await (0, _browsersHelper.checkBrowsers)(_utils.appDirectory);
      const port = await (0, _WebpackDevServerUtils.choosePort)('0.0.0.0', DEFAULT_PORT);

      if (port === null) {
        // We have not found a port.
        return;
      }

      const protocol = process.env.HTTPS === 'true' ? 'https' : 'http';
      const appName = _utils.pkg.name;
      const urls = (0, _WebpackDevServerUtils.prepareUrls)(protocol, HOST, port);
      const compiler = (0, _WebpackDevServerUtils.createCompiler)(_webpack.default, config, appName, urls, false); // Load proxy config

      const proxySetting = _utils.pkg.proxy;
      const proxyConfig = (0, _WebpackDevServerUtils.prepareProxy)(proxySetting, _paths.default.public); // Serve webpack assets generated by the compiler over a web server.

      const serverConfig = (0, _webpackDevServer2.default)(proxyConfig, urls.lanUrlForConfig);
      const devServer = new _webpackDevServer.default(compiler, serverConfig); // Launch WebpackDevServer.

      devServer.listen(port, HOST, err => {
        if (err) {
          console.log(err);
          return;
        }

        if (isInteractive) {
          (0, _clearConsole.default)();
        }

        console.log(_chalk.default.cyan('Starting the development server...\n'));
      });
      ['SIGINT', 'SIGTERM'].forEach(sig => {
        process.on(sig, () => {
          devServer.close();
          process.exit();
        });
      });
    } catch (err) {
      if (err && err.message) {
        console.log(err.message);
      }

      process.exit(1);
    }
  })();
}
//# sourceMappingURL=webpack.js.map