"use strict";

exports.__esModule = true;
exports.default = void 0;

var _fsExtra = require("fs-extra");

var _os = require("os");

var _path = require("path");

var _chalk = _interopRequireDefault(require("chalk"));

var _utils = require("./utils");

var _utils2 = require("../utils");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

(0, _fsExtra.ensureDirSync)((0, _path.join)((0, _os.tmpdir)(), 'gd-scripts', 'fixtures'));
const repos = ['https://github.com/GabrielDuarteM/youtube-autoclose-ads.git', 'https://github.com/GabrielDuarteM/copy-paste-component.git', 'https://github.com/GabrielDuarteM/copy-paste-component-vscode.git', 'https://github.com/GabrielDuarteM/pipe-now.git'];
const statuses = [];

const runFuncOnEveryRepo = async (func, message, currStep, totalSteps, afterFunc) => {
  for (let i = 0; i < repos.length; i++) {
    const repo = repos[i];
    const repoName = (0, _utils.getRepoName)(repo);
    (0, _utils2.logMessage)(`[${repoName} | ${i + 1}/${repos.length} | Step ${currStep}/${totalSteps}] ${message}`);
    const result = await func(repo);

    if (afterFunc) {
      afterFunc(result);
    }
  }
};

const logStatus = (repoName, status, spaceLength) => {
  console.log(`${repoName}${' '.repeat(spaceLength)}${status === 0 ? _chalk.default.green('SUCCESS') : _chalk.default.red('ERROR')}`);
};

const test = async () => {
  const totalSteps = 3;
  let currStep = 0;
  await runFuncOnEveryRepo(_utils.cloneOrPull, 'Cloning repo', currStep += 1, totalSteps);
  await runFuncOnEveryRepo(_utils.runYarnAddGdScripts, 'Installing the new version of gd-scripts', currStep += 1, totalSteps);
  await runFuncOnEveryRepo(_utils.runYarnCi, 'Running CI Script', currStep += 1, totalSteps, result => {
    statuses.push(result.status);
  });
  const results = statuses.reduce((acc, item, index) => [...acc, {
    repoName: (0, _utils.getRepoName)(repos[index]),
    status: item
  }], []);
  const longestNameLength = results.reduce((acc, item) => acc >= item.repoName.length ? acc : item.repoName.length, 0);
  console.log(`\n${_chalk.default.cyan('TEST RESULTS:')}`);
  console.log();
  results.forEach(result => {
    logStatus(result.repoName, result.status, longestNameLength - result.repoName.length + 2);
  });
  console.log();
  const finalStatus = statuses.some(x => x === 1) ? 1 : 0;
  process.exit(finalStatus);
};

var _default = test;
exports.default = _default;
//# sourceMappingURL=test.js.map